@@ -55,7 +55,6 @@ OC.L10N.register(
     "On events happening in a <strong>team</strong> of which you are a member" : "Kide zaren <strong>lantalde</strong> bateko gertaeretan",
     "Any important event in a <strong>team</strong> you are moderating" : "Moderatzen ari zaren <strong>lantalde</strong> bateko edozein gertaera garrantzitsu",
     "On global events happening in any <strong>team</strong>" : "<strong>Lantalde</strong> batean gertatzen diren gertaera orokorretan",
-    "Shared to Circles" : "Zirkuluetara partekatua",
     "Single" : "Bakana",
     "Personal" : "Pertsonala",
     "System" : "Sistema",
@@ -77,7 +76,7 @@ OC.L10N.register(
     "Nextcloud Group" : "Nextcloud taldea",
     "Email address" : "Helbide elektronikoa",
     "Contact" : "Kontaktua",
-    "Circle" : "Zirkulua",
+    "Team" : "Lantaldea",
     "Nextcloud App" : "Nextcloud aplikazioa",
     "Member" : "Kidea",
     "Moderator" : "Moderatzailea",
@@ -123,18 +122,21 @@ OC.L10N.register(
     "The account is already a member of this circle" : "Kontu hau zirkulu honetako kidea da dagoeneko",
     "The account has already been invited into this circle" : "Kontua zirkulu honetara gonbidatua izan da dagoeneko",
     "%s (Team owned by %s)" : "%s (%s-(r)en jabetzako lantaldea)",
-    "You are now a member of the Circle \"%2$s\"" : "«%2$s» zirkuluaren kide zara orain",
-    "You have been invited by %1$s into the Circle \"%2$s\"" : "%1$s(e)k «%2$s» zirkulura gonbidatu zaitu",
-    "%1$s sent a request to be a member of the Circle \"%2$s\"" : "%1$s(e)k «%2$s» zirkuluaren kide izateko eskaera bidali du",
+    "You are now a member of the Team \"%2$s\"" : "«%2$s» lantaldearen kide zara orain",
+    "You have been invited by %1$s into the Team \"%2$s\"" : "%1$s(e)k «%2$s» lantaldera gonbidatu zaitu",
+    "%1$s sent a request to be a member of the Team \"%2$s\"" : "%1$s(e)k «%2$s» lantaldearen kide izateko eskaera bidali du",
     "Accept" : "Onartu",
     "Refuse" : "Ukatu",
-    "Leave the circle" : "Utzi zirkulua",
+    "Leave the team" : "Utzi lantaldea",
     "%s" : "%s",
     "Personal team" : "Lantalde pertsonala",
     "%s owned by %s" : "%s jabea: %s",
     "You have no permission to create a new team" : "Ez duzu lantalde berri bat sortzeko baimenik",
     "%s shared a file with \"%s\"." : "%s fitxategi bat partekatu du \"%s\"(r)ekin.",
     "%s shared a file with you." : "%s zurekin fitxategi bat partekatu du.",
+    "%1$s shared %2$s with %3$s" : "%1$s-k  %2$s partekatu du %3$s-rekin",
+    "%1$s shared %2$s with \"%3$s\"" : "%1$s-k %2$s partekatu du \"%3$s\"-rekin",
+    "Open %s" : "Ireki %s",
     "%1$s shared some content with you.\nYou should have already received a separate email with a link to access it.\n" : "%1$s(e)k eduki batzuk partekatu ditu zurekin.\nBertara iristeko esteka mezu batean eduki behar zenuke dagoeneko zure posta elektronikoan.\n",
     "%1$s shared some content with you. You should have already received a separate email with a link to access it." : "%1$s(e)k eduki batzuk partekatu ditu zurekin. Bertara iristeko esteka mezu batean eduki behar zenuke dagoeneko zure posta elektronikoan.",
     "Password to access content shared with you by %1$s" : "%1$s-k zurekin partekatutako edukiera atzitzeko pasahitza",
@@ -142,59 +144,23 @@ OC.L10N.register(
     "This item is already shared with this team" : "Elementu hau dagoeneko partekatu da lantalde honekin",
     "Bring cloud-users closer together." : "Elkartu gehiago hodei erabiltzaileak.",
     "Teams allows people to create their own groups of people/colleagues/friends.\nThose groups of people can then be used by any other app for sharing purpose." : "Lantaldeak jendeak erabiltzaile/lankide/lagun taldeak sortzen ahalbidetzen die.\nPertsona talde hauek beste aplikazio batzuetan erabili daitezke partekatzeko xedearekin.",
+    "Failed to load teams" : "Lantaldeak kargatzeak huts egin du",
+    "Try again" : "Saiatu berriz",
+    "No teams found" : "Ez da lantalderik aurkitu",
+    "Join or create teams to see them here." : "Elkartu edo lantaldeak sortu, hemen ikusteko.",
+    "Create your first team" : "Sortu zure lehenengo lantaldea",
+    "Loading…" : "Kargatzen…",
+    "More teams" : "Lantalde gehiago",
     "No files in here" : "Ez dago fitxategirik hemen",
     "No entries found in this folder" : "Ez da sarrerarik aurkitu karpeta honetan ",
     "Name" : "Izena",
     "Size" : "Tamaina",
     "Modified" : "Aldatua",
-    "Circles" : "Zirkuluak",
-    "Circles' files" : "Zirkuluen fitxategiak",
-    "Select circles to filter by" : "Hautatu zirkuluak nola iragazi",
-    "No circles found" : "Ez da zirkulurik aurkitu",
-    "Please select circles to filter by" : "Hautatu zirkuluak nola iragazi",
-    "No files found for the selected circles" : "Ez da fitxategirik aurkitu hautatutako zirkuluetarako",
-    "You created the circle {circle}" : "{circle} zirkulua zuk sortu duzu",
-    "{author} created the circle {circle}" : "{author}(e)k {circle} zirkulua sortu du",
-    "You added circle {member} as member to {circle}" : "{member} zirkulua gehitu duzu kide gisa {circle}(e)ra",
-    "{author} added circle {member} has been added as member to {circle}" : "{author}(e)k {member} zirkulua gehitu du kide bezala {circle}(e)ra",
-    "You removed {member} leave {circle}" : "{member} kidea {circle}(e)tik atera duzu",
-    "On events happening in a <strong>Circle</strong> of which you are a member" : "Kide zaren <strong>zirkuluetako</strong> gertaeretan",
-    "Any important event in a <strong>Circle</strong> you are moderating" : "Moderatzen ari zaren <strong>zirkulu</strong> bateko edozein gertaera garrantzitsu",
-    "On global events happening in any <strong>Circle</strong>" : "<strong>Zirkulu</strong> batean gertatzen diren gertaera orokorretan",
-    "Join Request" : "Sartzeko eskaera",
-    "Password Protected" : "Pasahitzez babestua",
-    "Circle Invite" : "Zirkulu gonbidapena",
-    "Email Address" : "Helbide elektronikoa",
-    "Circle not found" : "Ez da zirkulua aurkitu",
-    "Circle not found " : "Ez da zirkulua aurkitu",
-    "This account is already a member of the circle" : "Kontu hau zirkuluko kidea da dagoeneko",
-    "Federated link not found" : "Ez da esteka federatua aurkitu",
-    "The circle is not federated" : "Zirkulua ez dago federatuta",
-    "You cannot join this circle" : "Ezin zara zirkulu honetan sartu",
-    "This member is the owner of the circle" : "Kide hau da zirkuluaren jabea",
-    "%s (Circle owned by %s)" : "%s (%s-(r)en jabetzako zirkulua)",
-    "Personal Circle" : "Zirkulu pertsonala",
-    "You need a specify a type of circle" : "Zirkulu mota zehaztu behar duzu",
-    "A circle with that name exists" : "Badago izen bereko beste zirkulu bat ",
-    "This member is not the owner of the circle" : "Kide hau ez da zirkuluaren jabea",
-    "This member is not an admin of the circle" : "Kide hau ez da zirkuluaren administratzailea",
-    "Group contains too many members" : "Taldeak kide gehiegi ditu",
-    "This group does not exist" : "Talde hau ez da existitzen",
-    "This group is already linked to the circle" : "Talde hau zirkuluarekin loturik dago dagoeneko",
-    "You cannot edit level in a personal circle" : "Ezin duzu maila aldatu zirkulu pertsonaletan",
-    "Group cannot be set as owner of a circle" : "Taldeak ezin dira zirkulu jabe bihurtu",
-    "now" : "orain",
-    "This account does not exist" : "Kontu hau ez da existitzen",
-    "Email format is not valid" : "Posta-helbidearen formatua ez da baliozkoa",
-    "This contact is not available" : "Kontaktu hori ez dago erabilgarri",
-    "You have no permission to create a new circle" : "Ez duzu zirkulu berri bat sortzeko baimenik",
-    "This item is already shared with this circle" : "Elementu hau dagoeneko partekatu da zirkulu honekin",
-    "Circles allows people to create their own groups of people/colleagues/friends.\nThose groups of people (or \"circles\") can then be used by any other app for sharing purpose." : "Circles jendeak erabiltzaile/lankide/lagun taldeak sortzen ahalbidetzen die.\nPertsona talde (edo \"zirkulu\") hauek beste aplikazio batzuetan erabili daitezke partekatzeko xedearekin. ",
     "Teams' files" : "Lantaldeen fitxategiak",
     "Select team to filter by" : "Hautatu iragazteko lantaldea",
-    "No teams found" : "Ez da lantalderik aurkitu",
     "Please select teams to filter by" : "Hautatu lantaldeak iragazteko",
     "No files found for the selected teams" : "Ez da fitxategirik aurkitu hautatutako lantaldeetarako",
-    "{author} added team {member} has been added as member to {circle}" : "{author}(e)k {member} lantaldea gehitu du kide bezala {circle}(e)ra"
+    "Shared to Circles" : "Zirkuluetara partekatua",
+    "Circle" : "Zirkulua"
 },
 "nplurals=2; plural=(n != 1);");
