@@ -2,11 +2,6 @@ OC.L10N.register(
     "circles",
     {
     "Teams" : "Equipos",
-    "Teams' files" : "Ficheiros dos equipos",
-    "Select team to filter by" : "Seleccione o equipo polo que filtrar",
-    "No teams found" : "Non se atoparon equipos",
-    "Please select teams to filter by" : "Seleccione os equipos polos que filtrar",
-    "No files found for the selected teams" : "Non se atoparon ficheiros para os equipos seleccionados",
     "You created the team {circle}" : "Vde. creou o equipo {circle}",
     "{author} created the team {circle}" : "{author} creou o equipo {circle}",
     "You deleted {circle}" : "Vde. eliminou {circle}",
@@ -60,7 +55,6 @@ OC.L10N.register(
     "On events happening in a <strong>team</strong> of which you are a member" : "En eventos que ocorren nun <strong>equípo</strong> do que  Vde. é membro",
     "Any important event in a <strong>team</strong> you are moderating" : "Calquera evento importante nun <strong>equipo</strong> do que Vde. é o moderador",
     "On global events happening in any <strong>team</strong>" : "En eventos globais que ocorren en calquera <strong>equipo</strong>",
-    "Shared to Circles" : "Compartido con Círculos",
     "Single" : "Individual",
     "Personal" : "Persoal",
     "System" : "Sistema",
@@ -82,7 +76,7 @@ OC.L10N.register(
     "Nextcloud Group" : "Grupo de Nextcloud",
     "Email address" : "Enderezo de correo",
     "Contact" : "Contacto",
-    "Circle" : "Círculo",
+    "Team" : "Equipo",
     "Nextcloud App" : "Aplicación Nextcloud",
     "Member" : "Membro",
     "Moderator" : "Moderador",
@@ -105,7 +99,7 @@ OC.L10N.register(
     "Password to access files" : "Contrasinal para acceder aos ficheiros",
     "%s shared multiple files with \"%s\"." : "%s compartiu varios ficheiros con «%s».",
     "%s shared multiple files with you." : "%s compartiu varios ficheiros con Vde.",
-    "Boot up" : "Arrincar",
+    "Boot up" : "Arrancar",
     "Nextcloud Initialization" : "Inicialización de Nextcloud",
     "Circles App Initialization" : "Inicialización da aplicación Círculos",
     "Fresh installation status" : "Estado da nova instalación",
@@ -128,18 +122,21 @@ OC.L10N.register(
     "The account is already a member of this circle" : "A conta xa é membro deste círculo",
     "The account has already been invited into this circle" : "A conta xa foi convidada a este círculo",
     "%s (Team owned by %s)" : "%s (Equipo propiedade de %s)",
-    "You are now a member of the Circle \"%2$s\"" : "Vde. agora é participante no círculo «%2$s»",
-    "You have been invited by %1$s into the Circle \"%2$s\"" : "Vde. foi convidado por %1$s ao círculo «%2$s»",
-    "%1$s sent a request to be a member of the Circle \"%2$s\"" : "%1$s enviou unha solicitude para ser participante no círculo «%2$s»",
+    "You are now a member of the Team \"%2$s\"" : "Vde. agora é participante no equipo «%2$s»",
+    "You have been invited by %1$s into the Team \"%2$s\"" : "Vde. foi convidado por %1$s ao equipo «%2$s»",
+    "%1$s sent a request to be a member of the Team \"%2$s\"" : "%1$s enviou unha solicitude para ser participante no equipo «%2$s»",
     "Accept" : "Aceptar",
     "Refuse" : "Rexeitar",
-    "Leave the circle" : "Deixar o círculo",
+    "Leave the team" : "Deixar o equipo",
     "%s" : "%s",
     "Personal team" : "Equipo persoal",
     "%s owned by %s" : "%s propiedade de %s",
     "You have no permission to create a new team" : "Vde. non ten permiso para crear un novo equipo",
     "%s shared a file with \"%s\"." : "%s compartiu un ficheiro con «%s».",
     "%s shared a file with you." : "%s compartiu un ficheiro con Vde.",
+    "%1$s shared %2$s with %3$s" : "%1$s compartiu %2$s con %3$s",
+    "%1$s shared %2$s with \"%3$s\"" : "%1$s compartiu %2$s con «%3$s»",
+    "Open %s" : "Abrir %s",
     "%1$s shared some content with you.\nYou should have already received a separate email with a link to access it.\n" : "%1$s compartiu algún contido con Vde.\nXa debería ter recibido un correo aparte cunha ligazón para acceder a el.\n",
     "%1$s shared some content with you. You should have already received a separate email with a link to access it." : "%1$s compartiu algún contido con Vde. Xa debería ter recibido un correo aparte cunha ligazón para acceder a el.",
     "Password to access content shared with you by %1$s" : "Contrasinal para acceder ao contido compartido con Vde. por %1$s",
@@ -147,54 +144,23 @@ OC.L10N.register(
     "This item is already shared with this team" : "Este elemento xa está compartido con este equipo",
     "Bring cloud-users closer together." : "Acercar aos usuarios da nube.",
     "Teams allows people to create their own groups of people/colleagues/friends.\nThose groups of people can then be used by any other app for sharing purpose." : "Os equipos permítelle ás persoas crear os seus propios grupos de persoas/colegas/amigos.\nEses grupos de persoas (ou «círculos») poden ser usados por calquera outra aplicación para compartir.",
+    "Failed to load teams" : "Produciuse un fallo ao cargar os equipos",
+    "Try again" : "Ténteo de novo",
+    "No teams found" : "Non se atopou ningún equipo",
+    "Join or create teams to see them here." : "Únase ou cree equipos para velos aquí.",
+    "Create your first team" : "Crear o seu primeiro equipo",
+    "Loading…" : "Cargando…",
+    "More teams" : "Máis equipos",
     "No files in here" : "Aquí non hai ficheiros",
-    "No entries found in this folder" : "Non se atoparon entradas neste cartafol",
+    "No entries found in this folder" : "Non se atopou ningunha entrada neste cartafol",
     "Name" : "Nome",
     "Size" : "Tamaño",
     "Modified" : "Modificado",
-    "Circles" : "Círculos",
-    "Circles' files" : "Ficheiros dos círculos",
-    "Select circles to filter by" : "Seleccionar círculos polos que filtrar",
-    "No circles found" : "Non se atoparon círculos",
-    "Please select circles to filter by" : "Seleccione os círculos polos que filtrar",
-    "No files found for the selected circles" : "Non se atoparon ficheiros para os círculos seleccionados",
-    "You created the circle {circle}" : "Vde. creou o círculo {circle}",
-    "{author} created the circle {circle}" : "{author} creou o círculo {circle}",
-    "You added circle {member} as member to {circle}" : "Vde. engadiu o círculo {member} como participante en {circle}",
-    "{author} added circle {member} has been added as member to {circle}" : "{author} engadiu o círculo {member} como participante en {circle}",
-    "You removed {member} leave {circle}" : "Vde. retirou a {member} de {circle}",
-    "On events happening in a <strong>Circle</strong> of which you are a member" : "En eventos que ocorren nun <strong>círculo</strong> do que  Vde. é membro",
-    "Any important event in a <strong>Circle</strong> you are moderating" : "Calquera evento importante nun Círculo do que Vde. é o moderador",
-    "On global events happening in any <strong>Circle</strong>" : "En eventos globais que ocorren en calquera <strong>círculo</strong>",
-    "Join Request" : "Solicitude para unirse",
-    "Password Protected" : "Protexido por contrasinal",
-    "Circle Invite" : "Convite ao círculo",
-    "Email Address" : "Enderezo de correo-e",
-    "Circle not found" : "Non se atopou o círculo",
-    "Circle not found " : "Non se atopou o círculo",
-    "This account is already a member of the circle" : "Esta conta xa é membro do círculo",
-    "Federated link not found" : "Non se atopou a ligazón federada",
-    "The circle is not federated" : "Este círculo non está federado",
-    "You cannot join this circle" : "Vde. non pode unirse a este círculo",
-    "This member is the owner of the circle" : "Este membro é o propietario do círculo",
-    "%s (Circle owned by %s)" : "%s (Círculo propiedade de %s)",
-    "Personal Circle" : "Círculo persoal",
-    "You need a specify a type of circle" : "Ten que especificar o tipo de círculo",
-    "A circle with that name exists" : "Xa existe un círculo con ese nome.",
-    "This member is not the owner of the circle" : "Este membro non é o propietario do círculo",
-    "This member is not an admin of the circle" : "Este membro non é o administrador do círculo",
-    "Group contains too many members" : "O grupo contén demasiados membros",
-    "This group does not exist" : "Non existe este grupo",
-    "This group is already linked to the circle" : "Este grupo xa está ligado co círculo",
-    "You cannot edit level in a personal circle" : "Vde. no pode editar o nivel nun círculo persoal",
-    "Group cannot be set as owner of a circle" : "O grupo non se pode definir como propietario dun círculo",
-    "now" : "agora",
-    "This account does not exist" : "Esta conta non existe",
-    "Email format is not valid" : "O formato do correo non é válido",
-    "This contact is not available" : "Este contacto non está dispoñíbel",
-    "You have no permission to create a new circle" : "Vde. non ten permiso para crear un novo círculo",
-    "This item is already shared with this circle" : "Este elemento xa está compartido con este círculo",
-    "Circles allows people to create their own groups of people/colleagues/friends.\nThose groups of people (or \"circles\") can then be used by any other app for sharing purpose." : "Círculos permítelle ás persoas crear os seus propios grupos de persoas/colegas/amigos.\nEses grupos de persoas (ou «círculos») poden ser usados por calquera outra aplicación para compartir.",
-    "{author} added team {member} has been added as member to {circle}" : "{author} engadiu o equipo {member} como participante en {circle}"
+    "Teams' files" : "Ficheiros dos equipos",
+    "Select team to filter by" : "Seleccione o equipo polo que filtrar",
+    "Please select teams to filter by" : "Seleccione os equipos polos que filtrar",
+    "No files found for the selected teams" : "Non se atopou ningún ficheiro para os equipos seleccionados",
+    "Shared to Circles" : "Compartido con Círculos",
+    "Circle" : "Círculo"
 },
 "nplurals=2; plural=(n != 1);");
