@@ -4,38 +4,13 @@ declare(strict_types=1);
 
 
 /**
- * Circles - Bring cloud-users closer together.
- *
- * This file is licensed under the Affero General Public License version 3 or
- * later. See the COPYING file.
- *
- * @author Maxence Lange <maxence@artificial-owl.com>
- * @copyright 2021
- * @license GNU AGPL version 3 or any later version
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU Affero General Public License as
- * published by the Free Software Foundation, either version 3 of the
- * License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU Affero General Public License for more details.
- *
- * You should have received a copy of the GNU Affero General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- *
+ * SPDX-FileCopyrightText: 2021 Nextcloud GmbH and Nextcloud contributors
+ * SPDX-License-Identifier: AGPL-3.0-or-later
  */
 
 
 namespace OCA\Circles\Command;
 
-use ArtificialOwl\MySmallPhpTools\Exceptions\InvalidItemException;
-use ArtificialOwl\MySmallPhpTools\Exceptions\ItemNotFoundException;
-use ArtificialOwl\MySmallPhpTools\Traits\Nextcloud\nc22\TNC22Deserialize;
-use ArtificialOwl\MySmallPhpTools\Traits\TArrayTools;
-use ArtificialOwl\MySmallPhpTools\Traits\TStringTools;
 use Exception;
 use OC\Core\Command\Base;
 use OCA\Circles\AppInfo\Application;
@@ -47,6 +22,11 @@ use OCA\Circles\Model\FederatedUser;
 use OCA\Circles\Model\Member;
 use OCA\Circles\Model\Probes\CircleProbe;
 use OCA\Circles\Service\ConfigService;
+use OCA\Circles\Tools\Exceptions\InvalidItemException;
+use OCA\Circles\Tools\Exceptions\ItemNotFoundException;
+use OCA\Circles\Tools\Traits\TArrayTools;
+use OCA\Circles\Tools\Traits\TDeserialize;
+use OCA\Circles\Tools\Traits\TStringTools;
 use Symfony\Component\Console\Helper\Table;
 use Symfony\Component\Console\Input\InputArgument;
 use Symfony\Component\Console\Input\InputInterface;
@@ -63,7 +43,7 @@ use Symfony\Component\Process\Process;
 class CirclesTest extends Base {
 	use TArrayTools;
 	use TStringTools;
-	use TNC22Deserialize;
+	use TDeserialize;
 
 
 	public static $INSTANCES = [
@@ -133,10 +113,10 @@ class CirclesTest extends Base {
 			 ->setDescription('testing some features')
 			 ->addArgument('deprecated', InputArgument::OPTIONAL, '')
 			 ->addOption(
-				 'are-you-aware-this-will-delete-all-my-data', '', InputOption::VALUE_REQUIRED,
-				 'Well, are you ?', ''
+			 	'are-you-aware-this-will-delete-all-my-data', '', InputOption::VALUE_REQUIRED,
+			 	'Well, are you ?', ''
 			 )
-			 ->addOption('skip-init', '', InputOption::VALUE_NONE, 'Bypass Initialisation')
+			 ->addOption('skip-init', '', InputOption::VALUE_NONE, 'Bypass Initialization')
 			 ->addOption('skip-setup', '', InputOption::VALUE_NONE, 'Bypass Circles Setup')
 			 ->addOption('only-setup', '', InputOption::VALUE_NONE, 'Stop after Circles Setup, pre-Sync');
 	}
@@ -157,7 +137,7 @@ class CirclesTest extends Base {
 		// loading CirclesManager
 		/** @var CirclesManager $circlesManager */
 		$circlesManager = \OC::$server->get(CirclesManager::class);
-//		$circlesManager->startSuperSession();
+		//		$circlesManager->startSuperSession();
 
 
 		$federatedUser = $circlesManager->getFederatedUser('test1', Member::TYPE_USER);
@@ -169,11 +149,11 @@ class CirclesTest extends Base {
 		//$probe->includePersonalCircles();
 
 		// get hidden circles (to get Groups)
-//		$probe->includeHiddenCircles();
+		//		$probe->includeHiddenCircles();
 
-//		$probe->includePersonalCircles();
-//		$probe->addOptionBool('filterPersonalCircles', true);
-//		$probe->mustBeMember();
+		//		$probe->includePersonalCircles();
+		//		$probe->addOptionBool('filterPersonalCircles', true);
+		//		$probe->mustBeMember();
 
 		$circles = $circlesManager->getCircles($probe);
 
@@ -182,18 +162,18 @@ class CirclesTest extends Base {
 		$output = new ConsoleOutput();
 		$table = new Table($output->section());
 		$table->setHeaders(['SingleId', 'Circle Name', 'Type']);
-		$table->render();
 
+		$rows = [];
 		foreach ($circles as $entry) {
-			$table->appendRow(
-				[
-					$entry->getSingleId(),
-					$entry->getDisplayName(),
-					Circle::$DEF_SOURCE[$entry->getSource()]
-				]
-			);
+			$rows[] = [
+				$entry->getSingleId(),
+				$entry->getDisplayName(),
+				Circle::$DEF_SOURCE[$entry->getSource()]
+			];
 		}
 
+		$table->setRows($rows);
+		$table->render();
 
 		return 0;
 		$federatedUser = $circlesManager->getFederatedUser('test1', Member::TYPE_USER);
@@ -205,7 +185,7 @@ class CirclesTest extends Base {
 		$federatedUser = $circlesManager->getFederatedUser('testGroup', Member::TYPE_GROUP);
 		echo 'singleId: ' . $federatedUser->getSingleId() . "\n";
 
-//		$federatedUser->getMemberships();
+		//		$federatedUser->getMemberships();
 
 
 		// get Circles available to test1
@@ -224,18 +204,19 @@ class CirclesTest extends Base {
 		$output = new ConsoleOutput();
 		$table = new Table($output->section());
 		$table->setHeaders(['SingleId', 'Circle Name', 'Type']);
-		$table->render();
 
+		$rows = [];
 		foreach ($circles as $entry) {
-			$table->appendRow(
-				[
-					$entry->getSingleId(),
-					$entry->getDisplayName(),
-					Circle::$DEF_SOURCE[$entry->getSource()]
-				]
-			);
+			$rows[] = [
+				$entry->getSingleId(),
+				$entry->getDisplayName(),
+				Circle::$DEF_SOURCE[$entry->getSource()]
+			];
 		}
 
+		$table->setRows($rows);
+		$table->render();
+
 
 		// exit
 		return 0;
@@ -248,12 +229,12 @@ class CirclesTest extends Base {
 		);
 
 		echo json_encode($members, JSON_PRETTY_PRINT);
-//		$circlesManager->startSession($federatedUser);
+		//		$circlesManager->startSession($federatedUser);
 
-//		$circlesManager->destroyCircle('XXHHLGdwQTxENgU');
-//		$circles = array_map(function(Circle $circle): string {
-//			return $circle->getDisplayName();
-//		}, $circlesManager->getCircles());
+		//		$circlesManager->destroyCircle('XXHHLGdwQTxENgU');
+		//		$circles = array_map(function(Circle $circle): string {
+		//			return $circle->getDisplayName();
+		//		}, $circlesManager->getCircles());
 		return 0;
 
 		$circlesManager->stopSession();
@@ -262,27 +243,27 @@ class CirclesTest extends Base {
 		//echo json_encode($circles, JSON_PRETTY_PRINT);
 
 
-//		$circle = $circlesManager->createCircle('This is a test2');
-//
-//
-//		$federatedUser2 = $circlesManager->getFederatedUser('test3', Member::TYPE_USER);
-//		$circlesManager->startSession($federatedUser);
-//
+		//		$circle = $circlesManager->createCircle('This is a test2');
+		//
+		//
+		//		$federatedUser2 = $circlesManager->getFederatedUser('test3', Member::TYPE_USER);
+		//		$circlesManager->startSession($federatedUser);
+		//
 		////		$info = $circlesManager->getCircle($circle->getSingleId());
 		////echo json_encode($info);
-//
-//		$circles = $circlesManager->getCircles();
-//		foreach ($circles as $circle) {
-//			echo $circle->getDisplayName() . "\n";
+		//
+		//		$circles = $circlesManager->getCircles();
+		//		foreach ($circles as $circle) {
+		//			echo $circle->getDisplayName() . "\n";
 		////			$circlesManager->startSession($federatedUser2);
 		////			$circlesManager->destroyCircle($circle->getSingleId());
-//		}
-//
-//
-//		// testing getCircle()
-//
-//
-//		return 0;
+		//		}
+		//
+		//
+		//		// testing getCircle()
+		//
+		//
+		//		return 0;
 
 
 		// testing queryHelper;
@@ -301,26 +282,26 @@ class CirclesTest extends Base {
 		/** @var FederatedUser $federatedUser */
 		$federatedUser = $circlesManager->getFederatedUser('test1', Member::TYPE_USER);
 
-//		$circlesQueryHelper->limitToInheritedMembers('test', 'shared_to', $federatedUser, true);
-//		$circlesQueryHelper->addCircleDetails('test', 'shared_to');
-//
-//		$items = [];
-//		$cursor = $qb->execute();
-//		while ($row = $cursor->fetch()) {
-//			try {
-//				$items[] = [
-//					'id'     => $row['id'],
-//					'data'   => $row['data'],
-//					'circle' => $circlesQueryHelper->extractCircle($row)
-//				];
-//			} catch (Exception $e) {
-//			}
-//		}
-//		$cursor->closeCursor();
-//
-//		echo json_encode($items, JSON_PRETTY_PRINT);
-//
-//		return 0;
+		//		$circlesQueryHelper->limitToInheritedMembers('test', 'shared_to', $federatedUser, true);
+		//		$circlesQueryHelper->addCircleDetails('test', 'shared_to');
+		//
+		//		$items = [];
+		//		$cursor = $qb->execute();
+		//		while ($row = $cursor->fetch()) {
+		//			try {
+		//				$items[] = [
+		//					'id'     => $row['id'],
+		//					'data'   => $row['data'],
+		//					'circle' => $circlesQueryHelper->extractCircle($row)
+		//				];
+		//			} catch (Exception $e) {
+		//			}
+		//		}
+		//		$cursor->closeCursor();
+		//
+		//		echo json_encode($items, JSON_PRETTY_PRINT);
+		//
+		//		return 0;
 
 
 		if ($input->getOption('are-you-aware-this-will-delete-all-my-data') === 'yes-i-am') {
@@ -368,11 +349,11 @@ class CirclesTest extends Base {
 
 		if (!$this->input->getOption('skip-setup')) {
 			if (!$this->input->getOption('skip-init')) {
-				$this->t('Initialisation Nextcloud');
+				$this->t('Nextcloud Initialization');
 				$this->initEnvironment();
 			}
 
-			$this->t('Initialisation Circles App');
+			$this->t('Circles App Initialization');
 			$this->reloadCirclesApp();
 			$this->configureCirclesApp();
 			$this->confirmVersion();
@@ -397,14 +378,14 @@ class CirclesTest extends Base {
 
 		$this->t('Adding local users and moderators');
 		$this->addLocalMemberByUserId();
-//		$this->addLocalMemberBySingleId();
-//		$this->addLocalMemberUsingMember();
-//		$this->levelLocalMemberToModerator();
-//		$this->addRemoteMemberUsingModerator();
-//		$this->addRemoteMemberUsingRemoteMember();
-//		$this->levelRemoteMemberToAdmin();
-//		$this->addRemoteMemberUsingRemoteAdmin();
-//
+		//		$this->addLocalMemberBySingleId();
+		//		$this->addLocalMemberUsingMember();
+		//		$this->levelLocalMemberToModerator();
+		//		$this->addRemoteMemberUsingModerator();
+		//		$this->addRemoteMemberUsingRemoteMember();
+		//		$this->levelRemoteMemberToAdmin();
+		//		$this->addRemoteMemberUsingRemoteAdmin();
+		//
 	}
 
 
