@@ -51,10 +51,13 @@ OC.L10N.register(
     "You do not have permission to create a file at the specified location" : "您無權在指定的位置創建檔案",
     "The file could not be converted." : "無法轉換檔案。",
     "Could not get relative path to converted file" : "無法取得轉換檔案的相對路徑",
+    "Limit must be a positive integer." : "限制必須為正整數。",
+    "The replacement character may only be a single character." : "替代字元僅限單一字元。",
+    "Filename sanitization already started." : "檔案名稱消毒流程已開始。",
+    "No filename sanitization inprogress." : "目前未執行檔案名稱的消毒流程。",
     "Favorite files" : "最愛的檔案",
     "No favorites" : "沒有最愛",
     "More favorites" : "更多最愛",
-    "Upload (max. %s)" : "上傳（上限 %s）",
     "Accept" : "接受",
     "Reject" : "拒絕",
     "Incoming ownership transfer from {user}" : "來自 {user} 的擁有權轉移",
@@ -69,10 +72,6 @@ OC.L10N.register(
     "The ownership transfer of {path} from {user} has completed." : "來自 {user} 的 \"{path}\" 所有權轉移已經完成",
     "in %s" : "在 %s",
     "Transferred from %1$s on %2$s" : "於 %2$s 從 %1$s 轉移",
-    "Files compatibility" : "檔案兼容性",
-    "Allow to restrict filenames to ensure files can be synced with all clients. By default all filenames valid on POSIX (e.g. Linux or macOS) are allowed." : "允許限製檔案名稱以確保檔案可以與所有客戶端同步。默認情況下，允許 POSIX（例如 Linux 或 macOS）上有效的所有檔案名稱。",
-    "Enforce Windows compatibility" : "實施 Windows 兼容性",
-    "This will block filenames not valid on Windows systems, like using reserved names or special characters. But this will not enforce compatibility of case sensitivity." : "這將阻止在 Windows 系統上無效的檔案名，例如使用保留名稱或特殊字元。但這不會強制區分大小寫的兼容性。",
     "File Management" : "檔案管理",
     "Home" : "主目錄",
     "Target folder does not exist any more" : "目標資料夾已經不存在了",
@@ -95,20 +94,28 @@ OC.L10N.register(
     "Invalid filename." : "檔案名稱無效。",
     "Renamed \"{oldName}\" to \"{newName}\"" : "已將「{oldName}」重新命名為「{newName}」",
     "Rename file" : "重新命名檔案",
+    "Folder" : "資料夾",
+    "Unknown file type" : "檔案類型不詳",
+    "{ext} image" : "{ext} 圖像",
+    "{ext} video" : "{ext} 視像",
+    "{ext} audio" : "{ext} 音頻",
+    "{ext} text" : "{ext} 文字",
     "Pending" : "待定的",
     "Unknown date" : "日期不詳",
     "Clear filter" : "清空過濾器",
     "Modified" : "修改時間",
+    "Search everywhere" : "到處搜尋",
     "Type" : "類型",
     "Active filters" : "有效的過濾器",
     "Remove filter" : "移除過濾",
     "Total rows summary" : "總列摘要",
     "Toggle selection for all files and folders" : "切換所有檔案和資料夾的選擇",
     "Name" : "名稱",
+    "File type" : "檔案類型",
     "Size" : "大小",
-    "\"{displayName}\" failed on some elements" : "“{displayName}” 在某些元素上失敗",
-    "\"{displayName}\" batch action executed successfully" : "成功執行 “{displayName}” 批處理操作",
-    "\"{displayName}\" action failed" : "“{displayName}” 操作失敗",
+    "{displayName}: failed on some elements" : "{displayName}：在部份元素上失敗",
+    "{displayName}: done" : "{displayName}：完成",
+    "{displayName}: failed" : "{displayName}：失敗",
     "Actions" : "操作",
     "(selected)" : "（已選擇）",
     "List of files and folders." : "檔案與資料夾清單。",
@@ -116,7 +123,11 @@ OC.L10N.register(
     "Column headers with buttons are sortable." : "具有按鈕的縱列標題可排序。",
     "This list is not fully rendered for performance reasons. The files will be rendered as you navigate through the list." : "出於性能考慮，此清單未完全呈現。檔案將在您瀏覽清單時呈現。",
     "File not found" : "找不到檔案",
-    "{count} selected" : "已選擇 {count} 項",
+    "_{count} selected_::_{count} selected_" : ["已選擇 {count} 項"],
+    "Search everywhere …" : "搜尋各處 …",
+    "Search here …" : "搜尋此處 …",
+    "Search scope options" : "搜尋範圍選項",
+    "Search here" : "搜尋此處",
     "{usedQuotaByte} used" : "已使用 {usedQuotaByte} ",
     "{used} of {quota} used" : "已使用 {quota} 當中的 {used}",
     "{relative}% used" : "已使用 {relative}%",
@@ -128,6 +139,25 @@ OC.L10N.register(
     "Create new folder" : "新增資料夾",
     "This name is already in use." : "這個用戶名稱已經有人使用了。",
     "Create" : "創建",
+    "Files starting with a dot are hidden by default" : "以點開頭的檔案默認為隱藏檔案",
+    "Failed to start filename sanitization." : "無法啟動檔案名稱消毒流程。",
+    "Failed to refresh filename sanitization status." : "無法刷新檔案名稱的消毒狀態。",
+    "Filename sanitization in progress." : "正在進行檔案名稱消毒。",
+    "Currently {processedUsers} of {totalUsers} accounts are already processed." : "目前已處理 {processedUsers} 個帳號，共 {totalUsers} 個。",
+    "Preparing …" : "正在準備 …",
+    "Refresh" : "刷新",
+    "All files have been santized for Windows filename support." : "所有檔案均已消毒以支援 Windows 檔案名稱規範。",
+    "Some files could not be sanitized, please check your logs." : "部份檔案無法完成消毒流程，請檢查您的紀錄檔。",
+    "Sanitization errors" : "消毒錯誤",
+    "Not sanitized filenames" : "未消毒的檔案名稱",
+    "Windows filename support has been enabled." : "已啟用 Windows 檔案名稱支援。",
+    "While this blocks users from creating new files with unsupported filenames, existing files are not yet renamed and thus still may break sync on Windows." : "雖然此設定可阻止使用者建立名稱不符合規範的新檔案，但若有尚未更名的既有檔案，在 Windows 系統上仍可能導致同步功能失效。",
+    "You can trigger a rename of files with invalid filenames, this will be done in the background and may take some time." : "您可以觸發對名稱無效的檔案進行重新命名，此操作將在背景執行，可能需要一段時間。",
+    "Please note that this may cause high workload on the sync clients." : "請注意，此操作可能會導致同步客戶端的工作負載過高。",
+    "Limit" : "限制",
+    "This allows to configure how many users should be processed in one background job run." : "此設定可決定單次背景工作執行中應處理多少使用者。",
+    "Sanitize filenames" : "消毒檔案名稱",
+    "(starting)" : "（正在開始）",
     "Fill template fields" : "填寫模板欄位",
     "Submitting fields …" : "正在遞交欄位 …",
     "Submit" : "遞交",
@@ -165,60 +195,72 @@ OC.L10N.register(
     "Error during upload: {message}" : "上傳時發生錯誤：{message}",
     "Error during upload, status code {status}" : "上傳期間發生錯誤，狀態代碼 {status}",
     "Unknown error during upload" : "上傳時發生未知的錯誤",
-    "\"{displayName}\" action executed successfully" : "成功執行 “{displayName}” 操作",
     "Loading current folder" : "目前資料夾加載中",
     "Retry" : "重試",
     "No files in here" : "沒有任何檔案",
     "Upload some content or sync with your devices!" : "在您的裝置同步或上傳一些內容！",
     "Go back" : "返回",
-    "Filter file names …" : "過濾檔案名稱 …",
     "Views" : "視圖",
     "Files settings" : "檔案設定",
     "Your files" : "您的檔案",
     "Open in files" : "在「檔案」應用程式中打開",
     "File cannot be accessed" : "檔案無法存取",
     "The file could not be found or you do not have permissions to view it. Ask the sender to share it." : "找不到該檔案，或是您沒有檢視該檔案的權限。請要求寄件者分享。",
+    "No search results for “{query}”" : "沒有結果符合「{query}」",
+    "Search for files" : "搜尋檔案",
     "Clipboard is not available" : "剪貼板不可用",
-    "WebDAV URL copied to clipboard" : "WebDAV 連結已複製到剪貼板",
+    "WebDAV URL copied" : "已複製 WebDAV URL",
+    "General" : "一般",
+    "Default view" : "默認檢視",
+    "All files" : "所有檔案",
+    "Personal files" : "個人檔案",
     "Sort favorites first" : "先排序最愛",
     "Sort folders before files" : "將資料夾在檔案之前排序",
+    "Folder tree" : "資料夾樹",
+    "Appearance" : "外觀",
     "Show hidden files" : "顯示隱藏檔案",
+    "Show file type column" : "顯示檔案類型縱列",
+    "Show file extensions" : "顯示副檔名",
     "Crop image previews" : "圖片裁剪預覽",
-    "Enable the grid view" : "啟用網格檢視",
-    "Enable folder tree" : "啟用資料夾樹狀結構",
     "Additional settings" : "其他設定",
     "WebDAV" : "WebDAV",
     "WebDAV URL" : "WebDAV URL",
-    "Copy to clipboard" : "複製到剪貼板",
-    "Use this address to access your Files via WebDAV" : "用這位址使用 WebDAV 存取你的檔案。",
-    "If you have enabled 2FA, you must create and use a new app password by clicking here." : "如果您啟用了 2FA，則必須通過單擊此處創建和使用新的應用程式密碼。",
+    "Copy" : "複製",
+    "How to access files using WebDAV" : "如何使用 WebDAV 存取檔案",
+    "Two-Factor Authentication is enabled for your account, and therefore you need to use an app password to connect an external WebDAV client." : "您的帳號已啟用兩階段驗證，因此您必須使用應用程式密碼才能連結外部 WebDAV 帳號。",
     "Warnings" : "警告",
-    "Prevent warning dialogs from open or reenable them." : "避免開啟警告對話框或重新啟用它們。",
-    "Show a warning dialog when changing a file extension." : "在變更副檔名時顯示警告對話框。",
+    "Warn before changing a file extension" : "變更副檔名前警告",
+    "Warn before deleting files" : "刪除檔案前警告",
     "Keyboard shortcuts" : "鍵盤快捷鍵",
-    "Speed up your Files experience with these quick shortcuts." : "這些快速捷徑可加快您的 Files 體驗。",
-    "Open the actions menu for a file" : "開啟檔案的操作選項單",
-    "Rename a file" : "重新命名檔案",
-    "Delete a file" : "刪除檔案",
-    "Favorite or remove a file from favorites" : "加入最愛或從最愛移除檔案",
-    "Manage tags for a file" : "管理檔案的標籤",
+    "File actions" : "檔案操作",
+    "Rename" : "重新命名",
+    "Delete" : "刪除",
+    "Add or remove favorite" : "新增或移除最愛",
+    "Manage tags" : "管理標籤",
     "Selection" : "選擇",
     "Select all files" : "選擇所有檔案",
-    "Deselect all files" : "取消選擇所有檔案",
-    "Select or deselect a file" : "選擇或取消選擇檔案",
-    "Select a range of files" : "選擇一系列檔案",
+    "Deselect all" : "取消全選",
+    "Select or deselect" : "選取或取消選取",
+    "Select a range" : "選取範圍",
     "Navigation" : "導覽列",
-    "Navigate to the parent folder" : "前往上層資料夾",
-    "Navigate to the file above" : "前往以上檔案",
-    "Navigate to the file below" : "前往以下檔案",
-    "Navigate to the file on the left (in grid mode)" : "前往左側的檔案（在網格模式下）",
-    "Navigate to the file on the right (in grid mode)" : "前往右側的檔案（在網格模式下）",
+    "Go to parent folder" : "前往上層資料夾",
+    "Go to file above" : "前往以上檔案",
+    "Go to file below" : "前往以下檔案",
+    "Go left in grid" : "在網格中向左",
+    "Go right in grid" : "在網格中向右",
     "View" : "檢視",
-    "Toggle the grid view" : "切換網格檢視",
-    "Open the sidebar for a file" : "開啟檔案側邊欄",
+    "Toggle grid view" : "切換網格檢視",
+    "Open file sidebar" : "開啟檔案側邊欄",
     "Show those shortcuts" : "顯示這些快捷鍵",
+    "Allow to restrict filenames to ensure files can be synced with all clients. By default all filenames valid on POSIX (e.g. Linux or macOS) are allowed." : "允許限製檔案名稱以確保檔案可以與所有客戶端同步。默認情況下，允許 POSIX（例如 Linux 或 macOS）上有效的所有檔案名稱。",
+    "After enabling the Windows compatible filenames, existing files cannot be modified anymore but can be renamed to valid new names by their owner." : "啟用 Windows 兼容檔案名後，現有的檔案無法再被修改，但其擁有者可以將其重新命名為有效的新名稱。",
+    "Failed to toggle Windows filename support" : "切換 Windows 檔案名稱支援失敗",
+    "Files compatibility" : "檔案兼容性",
+    "Enforce Windows compatibility" : "實施 Windows 兼容性",
+    "This will block filenames not valid on Windows systems, like using reserved names or special characters. But this will not enforce compatibility of case sensitivity." : "這將阻止在 Windows 系統上無效的檔案名，例如使用保留名稱或特殊字元。但這不會強制區分大小寫的兼容性。",
     "You" : "您",
     "Shared multiple times with different people" : "與不同的人多次分享",
+    "Unable to change the favorite state of the file" : "無法更改檔案的最愛狀態",
     "Error while loading the file data" : "載入檔案資料失敗",
     "Owner" : "擁有者",
     "Remove from favorites" : "從最愛中移除",
@@ -243,7 +285,6 @@ OC.L10N.register(
     "File successfully converted" : "成功轉換檔案",
     "Failed to convert file: {message}" : "無法轉換檔案：{message}",
     "Failed to convert file" : "無法轉換檔案",
-    "Deletion cancelled" : "刪除已取消",
     "Leave this share" : "保留該共用",
     "Leave these shares" : "保留這些分享",
     "Disconnect storage" : "解除連結儲存空間",
@@ -254,39 +295,38 @@ OC.L10N.register(
     "Delete files" : "刪除檔案",
     "Delete folder" : "刪除資料夾",
     "Delete folders" : "刪除資料夾",
-    "Delete" : "刪除",
     "_You are about to permanently delete {count} item_::_You are about to permanently delete {count} items_" : ["您即將永久刪除 {count} 個項目"],
     "_You are about to delete {count} item_::_You are about to delete {count} items_" : ["您即將刪除 {count} 個項目"],
     "Confirm deletion" : "確認刪除",
     "Cancel" : "取消",
+    "Download" : "下載",
+    "The requested file is not available." : "無法取得所要求的檔案。",
+    "The requested files are not available." : "無法取得所要求的檔案。",
     "Moving \"{source}\" to \"{destination}\" …" : "正在移動「{source}」至「{destination}」…",
     "Copying \"{source}\" to \"{destination}\" …" : "正在複製「{source}」至「{destination}」…",
+    "Destination is not a folder" : "目標地不是資料夾",
+    "This file/folder is already in that directory" : "此檔案/資料夾已在該目錄中",
     "You cannot move a file/folder onto itself or into a subfolder of itself" : "您無法將檔案/資料夾移動到其自身或子資料夾中",
     "(copy)" : "（複本）",
     "(copy %n)" : "（複本 %n）",
-    "Move cancelled" : "移動已取消",
     "A file or folder with that name already exists in this folder" : "此資料夾中已存在同名的檔案或資料夾",
     "The files are locked" : "檔案已被上鎖",
     "The file does not exist anymore" : "檔案已不存在",
     "Choose destination" : "選擇目標地",
     "Copy to {target}" : "複製到 {target}",
-    "Copy" : "複製",
     "Move to {target}" : "移動到 {target}",
     "Move" : "移動",
     "Move or copy operation failed" : "移動或複製操作失敗",
     "Move or copy" : "移動或複製",
-    "Cancelled move or copy of \"{filename}\"." : "已取消移動或複製 \"{filename}\"。",
-    "Cancelled move or copy operation" : "已取消移動或複製操作",
     "Open folder {displayName}" : "打開資料夾 {displayName}",
     "Open in Files" : "在「檔案」應用程式中打開",
+    "Open locally" : "在近端打開",
+    "Failed to redirect to client" : "無法重定向到客戶端",
     "Open file locally" : "在近端打開檔案",
     "The file should now open on your device. If it doesn't, please check that you have the desktop app installed." : "檔案現在應該在您的裝置上打開。如果沒有，請檢查您是否已安裝桌面應用程式。",
     "Retry and close" : "重試和關閉",
     "Open online" : "線上開啟",
-    "Failed to redirect to client" : "無法重定向到客戶端",
-    "Open locally" : "在近端打開",
-    "Rename" : "重新命名",
-    "Open details" : "開啟細節",
+    "Details" : "詳細資料",
     "View in folder" : "在資料夾中檢視",
     "Today" : "今日",
     "Last 7 days" : "過去7日",
@@ -299,15 +339,15 @@ OC.L10N.register(
     "PDFs" : "PDF",
     "Folders" : "資料夾",
     "Audio" : "音頻",
-    "Photos and images" : "照片與圖像",
+    "Images" : "圖像",
     "Videos" : "影片",
-    "New folder creation cancelled" : "已取消建立新資料夾",
     "Created new folder \"{name}\"" : "創建了新資料夾 \"{name}\"",
     "Unable to initialize the templates directory" : "無法初始化模板目錄",
     "Create templates folder" : "創建模板資料夾",
     "Templates" : "模板",
     "New template folder" : "新範本資料夾",
     "In folder" : "在資料夾中",
+    "Search in all files" : "在所有檔案中搜尋",
     "Search in folder: {folder}" : "搜尋資料夾： {folder}",
     "One of the dropped files could not be processed" : "無法處理其中一個投放的檔案",
     "Your browser does not support the Filesystem API. Directories will not be uploaded" : "您的瀏覽器不支援檔案系統 API。將不會上傳目錄",
@@ -322,15 +362,16 @@ OC.L10N.register(
     "Files moved successfully" : "檔案移動成功",
     "Conflicts resolution skipped" : "已略過衝突解決",
     "Upload cancelled" : "上傳已取消",
+    "Could not rename \"{oldName}\", it does not exist any more" : "無法命名檔案「{oldName}」，因為此檔案已經不存在",
+    "The name \"{newName}\" is already used in the folder \"{dir}\". Please choose a different name." : "此名稱「{newName}」在這資料夾「{dir}」已經被使用。請選擇其他名稱。",
+    "Could not rename \"{oldName}\"" : "無法重新命名「{oldName}」",
     "This operation is forbidden" : "此操作被禁止",
-    "This directory is unavailable, please check the logs or contact the administrator" : "這個目錄無法存取，請檢查伺服器記錄檔或聯絡管理員",
+    "This folder is unavailable, please try again later or contact the administration" : "此資料夾無法使用，請稍後再試或聯絡管理員",
     "Storage is temporarily not available" : "儲存空間暫時無法使用",
     "Unexpected error: {error}" : "意外錯誤：{error}",
-    "_{folderCount} folder_::_{folderCount} folders_" : ["{folderCount} 個資料夾"],
-    "_{fileCount} file_::_{fileCount} files_" : ["{fileCount} 個檔案"],
-    "_1 file and {folderCount} folder_::_1 file and {folderCount} folders_" : ["1 個檔案與 {folderCount} 個資料夾"],
-    "_{fileCount} file and 1 folder_::_{fileCount} files and 1 folder_" : ["{fileCount} 個檔案與 1 個資料夾"],
-    "{fileCount} files and {folderCount} folders" : "{fileCount} 個檔案與 {folderCount} 個資料夾",
+    "_%n file_::_%n files_" : ["%n 個檔案"],
+    "_%n folder_::_%n folders_" : ["%n 個資料夾"],
+    "_%n hidden_::_%n hidden_" : ["%n 個隱藏"],
     "Filename must not be empty." : "檔案名稱不能為空。",
     "\"{char}\" is not allowed inside a filename." : "檔案名稱中不允許出現「{char}」",
     "\"{segment}\" is a reserved name and not allowed for filenames." : "「{segment}」是保留名稱，不允許用在檔案名稱。",
@@ -339,10 +380,7 @@ OC.L10N.register(
     "List of favorite files and folders." : "最愛檔案與資料夾的清單。",
     "No favorites yet" : "尚無最愛",
     "Files and folders you mark as favorite will show up here" : "您標記為最愛的檔案與資料夾將會顯示在這裡",
-    "All files" : "所有檔案",
     "List of your files and folders." : "您的檔案與資料夾清單。",
-    "All folders" : "所有資料夾",
-    "Personal files" : "個人檔案",
     "List of your files and folders that are not shared." : "未分享的檔案與資料夾清單。",
     "No personal files found" : "找不到個人檔案",
     "Files that are not shared will show up here." : "尚未分享的檔案將會顯示在此處。",
@@ -350,12 +388,13 @@ OC.L10N.register(
     "List of recently modified files and folders." : "最近修改的檔案和資料夾的清單。",
     "No recently modified files" : "近期無修改檔案",
     "Files and folders you recently modified will show up here." : "您最近修改的檔案和資料夾將顯示在此處。",
+    "Search" : "搜尋",
+    "Search results within your files." : "在您的檔案中搜尋結果",
     "No entries found in this folder" : "在此資料夾中沒有任何項目",
     "Select all" : "全選",
     "Upload too large" : "上傳過大",
     "The files you are trying to upload exceed the maximum size for file uploads on this server." : "您試圖上傳的檔案大小超過伺服器的限制",
     "File could not be found" : "找不到檔案",
-    "Download" : "下載",
     "Show list view" : "顯示清單視圖",
     "Show grid view" : "顯示網格視圖",
     "Close" : "關閉",
@@ -380,12 +419,12 @@ OC.L10N.register(
     "Edit locally" : "在近端編輯",
     "Open" : "開啟",
     "Could not load info for file \"{file}\"" : "無法讀取 \"{file}\" 的詳細資料",
-    "Details" : "詳細資料",
     "Please select tag(s) to add to the selection" : "請選擇要添加到所選項目中的標籤",
     "Apply tag(s) to selection" : "將標籤應用於所選項目",
     "Select directory \"{dirName}\"" : "選擇目錄「{dirName}」",
     "Select file \"{fileName}\"" : "選擇檔案「{fileName}」",
     "Unable to determine date" : "無法確定日期",
+    "This directory is unavailable, please check the logs or contact the administrator" : "這個目錄無法存取，請檢查伺服器記錄檔或聯絡管理員",
     "Could not move \"{file}\", target exists" : "無法移動「{file}」，目標已經存在",
     "Could not move \"{file}\"" : "無法移動 \"{file}\"",
     "copy" : "複製",
@@ -394,9 +433,6 @@ OC.L10N.register(
     "Copied {origin} inside {destination}" : "已複製 {origin} 至 {destination}",
     "Copied {origin} and {nbfiles} other files inside {destination}" : "已複製 {origin} 和其他 {nbfiles} 個檔案至 {destination}",
     "{newName} already exists" : "{newName} 已經存在",
-    "Could not rename \"{fileName}\", it does not exist any more" : "無法命名檔案 \"{fileName}\"，因為此檔案已經不存在",
-    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "此名稱 \"{targetName}\" 在這資料夾 \"{dir}\" 已經被使用。請重新選擇不同的名稱",
-    "Could not rename \"{fileName}\"" : "無法重新命名「{fileName}」",
     "Could not create file \"{file}\"" : "無法建立檔案 \"{file}\"",
     "Could not create file \"{file}\" because it already exists" : "無法建立檔案「{file}」，因為此檔案已存在",
     "Could not create folder \"{dir}\" because it already exists" : "無法建立資料夾 \"{dir}\"，因為此資料夾已存在",
@@ -404,8 +440,6 @@ OC.L10N.register(
     "Error deleting file \"{fileName}\"." : "刪除 \"{fileName}\" 出錯",
     "No search results in other folders for {tag}{filter}{endtag}" : "在其它資料夾中沒有找到 {tag}{filter}{endtag}",
     "Enter more than two characters to search in other folders" : "輸入兩個字元以上以便在其它資料夾搜尋",
-    "_%n folder_::_%n folders_" : ["%n 個資料夾"],
-    "_%n file_::_%n files_" : ["%n 個檔案"],
     "{dirs} and {files}" : "{dirs} 和 {files}",
     "_including %n hidden_::_including %n hidden_" : ["包括 %n 個隱藏檔"],
     "You do not have permission to upload or create files here" : "您無權限上傳或建立檔案",
@@ -431,30 +465,63 @@ OC.L10N.register(
     "Direct link was copied (only works for people who have access to this file/folder)" : "已複製直接連結（僅適用於有權訪問此檔案/資料夾的人仕）",
     "Path" : "路徑",
     "_%n byte_::_%n bytes_" : ["%n 位元組"],
-    "Favorited" : "已加入最愛",
+    "Favored" : "已加入最愛",
+    "Favor" : "加入最愛",
     "Copy direct link (only works for people who have access to this file/folder)" : "複製直接連結（只對能存取的人仕有用）",
     "Upload file" : "上傳檔案",
-    "Not favorited" : "未加入至最愛",
+    "Not favored" : "未加入最愛",
     "An error occurred while trying to update the tags" : "更新標籤時發生錯誤",
-    "You don't have permission to upload or create files here." : "您無權在此上傳或建立檔案。",
-    "Storage informations" : "儲存資訊",
-    "Choose file" : "選擇檔案",
-    "Go to the previous folder" : "前往上一個資料夾",
-    "Open the files app settings" : "開啟 Files 應用程式設定",
-    "Unable to change the favourite state of the file" : "無法更改檔案的最愛狀態",
-    "Edit file locally" : "在近端編輯檔案",
-    "Edit online" : "在線編輯",
-    "Create new templates folder" : "創建新範本資料夾",
-    "List of favorites files and folders." : "最愛檔案與資料夾的清單。",
+    "Upload (max. %s)" : "上傳（上限 %s）",
+    "\"{displayName}\" action executed successfully" : "成功執行 “{displayName}” 操作",
+    "\"{displayName}\" action failed" : "“{displayName}” 操作失敗",
+    "\"{displayName}\" failed on some elements" : "“{displayName}” 在某些元素上失敗",
+    "\"{displayName}\" batch action executed successfully" : "成功執行 “{displayName}” 批處理操作",
+    "Submitting fields…" : "正在遞交欄位 …",
+    "Filter filenames…" : "過濾檔案名 ...",
+    "WebDAV URL copied to clipboard" : "WebDAV 連結已複製到剪貼板",
+    "Enable the grid view" : "啟用網格檢視",
+    "Enable folder tree" : "啟用資料夾樹狀結構",
+    "Copy to clipboard" : "複製到剪貼板",
+    "Use this address to access your Files via WebDAV" : "用這位址使用 WebDAV 存取你的檔案。",
+    "If you have enabled 2FA, you must create and use a new app password by clicking here." : "如果您啟用了 2FA，則必須通過單擊此處創建和使用新的應用程式密碼。",
+    "Deletion cancelled" : "刪除已取消",
+    "Move cancelled" : "移動已取消",
+    "Cancelled move or copy of \"{filename}\"." : "已取消移動或複製 \"{filename}\"。",
+    "Cancelled move or copy operation" : "已取消移動或複製操作",
+    "Open details" : "開啟細節",
+    "Photos and images" : "照片與圖像",
+    "New folder creation cancelled" : "已取消建立新資料夾",
+    "_{folderCount} folder_::_{folderCount} folders_" : ["{folderCount} 個資料夾"],
+    "_{fileCount} file_::_{fileCount} files_" : ["{fileCount} 個檔案"],
+    "_1 file and {folderCount} folder_::_1 file and {folderCount} folders_" : ["1 個檔案與 {folderCount} 個資料夾"],
+    "_{fileCount} file and 1 folder_::_{fileCount} files and 1 folder_" : ["{fileCount} 個檔案與 1 個資料夾"],
+    "{fileCount} files and {folderCount} folders" : "{fileCount} 個檔案與 {folderCount} 個資料夾",
+    "All folders" : "所有資料夾",
     "Personal Files" : "個人檔案",
     "Text file" : "文字檔",
     "New text file.txt" : "新文字檔.txt",
-    "Favored" : "已加入最愛",
-    "Favor" : "加入最愛",
-    "Not favored" : "未加入最愛",
-    "Submitting fields…" : "正在遞交欄位 …",
-    "Filter filenames…" : "過濾檔案名 ...",
-    "{count} files could not be converted" : "{count} 個檔案無法轉換",
-    "{count} files successfully converted" : "{count} 個檔案成功轉換"
+    "%1$s (renamed)" : "%1$s（已重新命名）",
+    "renamed file" : "已重新命名的檔案",
+    "After enabling the windows compatible filenames, existing files cannot be modified anymore but can be renamed to valid new names by their owner." : "啟用 Windows 兼容檔案名後，現有的檔案無法再被修改，但其擁有者可以將其重新命名為有效的新名稱。",
+    "It is also possible to migrate files automatically after enabling this setting, please refer to the documentation about the occ command." : "啟用此設定後，還可以自動遷移檔案，請參考有關 occ 指令的說明書。",
+    "Filter file names …" : "過濾檔案名稱 …",
+    "Prevent warning dialogs from open or reenable them." : "避免開啟警告對話框或重新啟用它們。",
+    "Show a warning dialog when changing a file extension." : "在變更副檔名時顯示警告對話框。",
+    "Speed up your Files experience with these quick shortcuts." : "這些快速捷徑可加快您的 Files 體驗。",
+    "Open the actions menu for a file" : "開啟檔案的操作選項單",
+    "Rename a file" : "重新命名檔案",
+    "Delete a file" : "刪除檔案",
+    "Favorite or remove a file from favorites" : "加入最愛或從最愛移除檔案",
+    "Manage tags for a file" : "管理檔案的標籤",
+    "Deselect all files" : "取消選擇所有檔案",
+    "Select or deselect a file" : "選擇或取消選擇檔案",
+    "Select a range of files" : "選擇一系列檔案",
+    "Navigate to the parent folder" : "前往上層資料夾",
+    "Navigate to the file above" : "前往以上檔案",
+    "Navigate to the file below" : "前往以下檔案",
+    "Navigate to the file on the left (in grid mode)" : "前往左側的檔案（在網格模式下）",
+    "Navigate to the file on the right (in grid mode)" : "前往右側的檔案（在網格模式下）",
+    "Toggle the grid view" : "切換網格檢視",
+    "Open the sidebar for a file" : "開啟檔案側邊欄"
 },
 "nplurals=1; plural=0;");
