@@ -13,9 +13,12 @@ OC.L10N.register(
     "Cancel" : "বাতিল করুন",
     "URL" : "URL",
     "to" : "প্রতি",
+    "Upload" : "আপলোড",
     "Edit" : "সম্পাদনা",
+    "Done" : "শেষ হলো",
+    "Details" : "বিসতারিত",
+    "Choose" : "বেছে নিন",
     "Info" : "Info",
-    "Warning" : "সতর্কবাণী",
-    "Details" : "বিসতারিত"
+    "Warning" : "সতর্কবাণী"
 },
 "nplurals=2; plural=(n != 1);");
