@@ -12,9 +12,9 @@ OC.L10N.register(
     "The given color is invalid" : "La couleur donnée est invalide",
     "Disable-user-theming should be true or false" : "Désactiver le thème de l'utilisateur doit valoir vrai ou faux.",
     "Saved" : "Enregistré",
-    "Invalid app given" : "Application invalide indiquée",
-    "Invalid type for setting \"defaultApp\" given" : "Type non valide pour le paramètre \"defaultApp\" donné",
-    "Invalid setting key" : "Clé de réglage non valide",
+    "Invalid app given" : "Application fournie non valide",
+    "Invalid type for setting \"defaultApp\" given" : "Type non valide pour le paramètre \"defaultApp\" fourni",
+    "Invalid setting key" : "Clé de paramétrage non valide",
     "The file was uploaded" : "Le fichier a été téléversé",
     "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Le fichier téléversé dépasse la valeur upload_max_filesize située dans le fichier php.ini",
     "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Le fichier téléversé dépasse la valeur MAX_FILE_SIZE spécifiée dans le formulaire HTML",
@@ -29,7 +29,7 @@ OC.L10N.register(
     "Appearance and accessibility" : "Apparence et accessibilité",
     "PHP Imagick module" : "Module PHP Imagick",
     "The PHP module \"imagick\" is not enabled although the theming app is. For favicon generation to work correctly, you need to install and enable this module." : "Le module PHP \"imagick\" n’est pas actif mais l’application Theming est activée. Pour que la génération du Favicon fonctionne correctement, ce module doit être installé et actif.",
-    "The PHP module \"imagick\" in this instance has no SVG support. For better compatibility it is recommended to install it." : "Le module PHP « imagick » n’a aucun support SVG dans cette instance. Pour une meilleure compatibilité, il est recommandé de l’installer.",
+    "The PHP module \"imagick\" in this instance has no SVG support. For better compatibility it is recommended to install it." : "Le module PHP « imagick » n’a aucune prise en charge du SVG dans cette instance. Pour une meilleure compatibilité, il est recommandé de l’installer.",
     "Dark theme with high contrast mode" : "Thème sombre avec mode de contraste élevé",
     "Enable dark high contrast mode" : "Activer le mode sombre à contraste élevé",
     "Similar to the high contrast mode, but with dark colours." : "Similaire au mode de contraste élevé, mais avec des couleurs sombres.",
@@ -75,6 +75,7 @@ OC.L10N.register(
     "Background and login image" : "Image d'arrière-plan et de connexion",
     "Advanced options" : "Options avancées",
     "Install the ImageMagick PHP extension with support for SVG images to automatically generate favicons based on the uploaded logo and color." : "Installez l'extension PHP ImageMagick qui prend en charge les images SVG pour générer automatiquement des favicons à partir du logo téléversé et de la couleur indiquée.",
+    "Universal access is very important to us. We follow web standards and check to make everything usable also without mouse, and assistive software such as screenreaders. We aim to be compliant with the {linkstart}Web Content Accessibility Guidelines{linkend} 2.1 on AA level, with the high contrast theme even on AAA level." : "L’accès universel est très important pour nous. Nous suivons les standards du web et nous assurons que tout soit également utilisable sans souris et avec des logiciels d’assistance technique tels que les lecteurs d’écran. Nous visons à respecter les {linkstart}Règles pour l’accessibilité des contenus Web{linkend} 2.1 de niveau AA et même de niveau AAA avec le thème à fort contraste.",
     "If you find any issues, do not hesitate to report them on {issuetracker}our issue tracker{linkend}. And if you want to get involved, come join {designteam}our design team{linkend}!" : "Si vous rencontrez des problèmes, n'hésitez pas à les signaler sur {issuetracker}notre outil de suivi des problèmes{linkend}. Et si vous voulez vous impliquer, venez rejoindre {designteam}notre équipe de design{linkend} !",
     "Unable to apply the setting." : "Impossible d'appliquer le réglage.",
     "Appearance and accessibility settings" : "Paramètres d’apparence et d’accessibilité",
@@ -82,14 +83,14 @@ OC.L10N.register(
     "Enable blur background filter (may increase GPU load)" : "Activer le filtre flou de l'arrière-plan (peut augmenter la charge du GPU)",
     "Customization has been disabled by your administrator" : "La personnalisation a été désactivée par votre administrateur",
     "Set a primary color to highlight important elements. The color used for elements such as primary buttons might differ a bit as it gets adjusted to fulfill accessibility requirements." : "Définissez une couleur principale pour mettre en évidence les éléments importants. La couleur utilisée pour les éléments tels que les boutons primaires peut varier légèrement en fonction des exigences d'accessibilité.",
-    "Background and color" : "Image d’arrière-plan et couleur",
+    "Background and color" : "Arrière-plan et couleur",
     "The background can be set to an image from the default set, a custom uploaded image, or a plain color." : "L'arrière-plan peut être une image du catalogue par défaut, une image personnalisée téléversée ou une couleur unie.",
     "Keyboard shortcuts" : "Raccourcis clavier",
     "In some cases keyboard shortcuts can interfere with accessibility tools. In order to allow focusing on your tool correctly you can disable all keyboard shortcuts here. This will also disable all available shortcuts in apps." : "Dans certains cas, les raccourcis clavier peuvent interférer avec les outils d'accessibilité. Afin de vous permettre de vous concentrer correctement sur votre outil, vous pouvez désactiver tous les raccourcis clavier ici. Cela désactivera également tous les raccourcis disponibles dans les applications.",
     "Disable all keyboard shortcuts" : "Désactiver tous les raccourcis clavier",
-    "Current selected app: {app}, position {position} of {total}" : "L'application sélectionnée actuelle : {app}, position {position} de {total}",
-    "Move up" : "Monter",
-    "Move down" : "Descendre",
+    "Current selected app: {app}, position {position} of {total}" : "L'application sélectionnée actuelle : {app}, position {position} sur {total}",
+    "Move up" : "Déplacer vers le haut",
+    "Move down" : "Déplacer vers le bas",
     "Select a background from your files" : "Sélectionner un arrière-plan parmi vos fichiers",
     "Select background" : "Sélectionner un arrière-plan",
     "No background has been selected" : "Aucun arrière-plan n'a été sélectionné",
@@ -110,8 +111,8 @@ OC.L10N.register(
     "Default app" : "Application par défaut",
     "The default app is the app that is e.g. opened after login or when the logo in the menu is clicked." : "L'application par défaut est l'application qui, par exemple, s'ouvre après une connexion ou lorsque l'on clique sur le logo du menu.",
     "Use custom default app" : "Utiliser l'application par défaut personnalisée",
-    "Global default app" : "Application par défaut globale",
-    "Global default apps" : "Applications par défaut globales",
+    "Global default app" : "Application globale par défaut",
+    "Global default apps" : "Applications globales par défaut",
     "Default app priority" : "Priorité de l'application par défaut",
     "If an app is not enabled for a user, the next app with lower priority is used." : "Si une application n'est pas activée pour un utilisateur, l'application suivante avec une priorité plus basse sera utilisée.",
     "Select a custom color" : "Sélectionnez une couleur personnalisée",
