@@ -1,25 +1,18 @@
 OC.L10N.register(
     "twofactor_backupcodes",
     {
-    "_" : "_",
-    "An error occurred while generating your backup codes" : "Tapahtui virhe varakoodeja luotaessa",
-    "These are your backup codes. Please save and/or print them as you will not be able to read the codes again later" : "Nämä ovat varakoodisi. Tallenna ja/tai tulosta ne, koska et voi lukea koodeja myöhemmin",
-    "Save backup codes" : "Tallenna varakoodit",
-    "Print backup codes" : "Tulosta varakoodit",
-    "Backup codes have been generated. {used} of {total} codes have been used." : "Varakoodit on luotu. {used}/{total} koodia on käytetty.",
-    "Regenerate backup codes" : "Luo varakoodit uudelleen",
-    "_icon-loading-small_::_generate-backup-codes_" : ["icon-loading-small","generate-backup-codes"],
-    "If you regenerate backup codes, you automatically invalidate old codes." : "Jos luot varakoodit uudelleen, vanhat koodit poistetaan automaattisesti käytöstä.",
-    "Generate backup codes" : "Luo varakoodit",
     "You created two-factor backup codes for your account" : "Loit kaksivaiheisen tunnistautumisen varakoodit tilillesi",
     "Second-factor backup codes" : "Kaksivaiheisen tunnistautumisen varakoodit",
+    "Generate backup codes" : "Luo varakoodit",
     "Backup code" : "Varakoodi",
     "Use backup code" : "Käytä varakoodia",
     "Two factor backup codes" : "Kaksivaiheiden tunnistautumisen varakoodit",
-    "activated" : "aktivoitu",
-    "updated" : "päivitetty",
-    "created" : "luotu",
-    "destroyed" : "tuhottu",
-    "Nextcloud backup codes" : "Nextcloud-varakoodit"
+    "An error occurred while generating your backup codes" : "Tapahtui virhe varakoodeja luotaessa",
+    "Backup codes have been generated. {used} of {total} codes have been used." : "Varakoodit on luotu. {used}/{total} koodia on käytetty.",
+    "Save backup codes" : "Tallenna varakoodit",
+    "Print backup codes" : "Tulosta varakoodit",
+    "Regenerate backup codes" : "Luo varakoodit uudelleen",
+    "If you regenerate backup codes, you automatically invalidate old codes." : "Jos luot varakoodit uudelleen, vanhat koodit poistetaan automaattisesti käytöstä.",
+    "Submit" : "Lähetä"
 },
 "nplurals=2; plural=(n != 1);");
