@@ -129,6 +129,8 @@ OC.L10N.register(
     "Settings" : "Socruithe",
     "Log out" : "Logáil Amach",
     "Accounts" : "Cuntais",
+    "Bluesky" : "Bluesky",
+    "View %s on Bluesky" : "Féach %s ar Bluesky",
     "Email" : "Ríomhphost",
     "Mail %s" : "Ríomhphost %s",
     "Fediverse" : "Feidearálach",
@@ -144,7 +146,7 @@ OC.L10N.register(
     "About" : "Faoi",
     "Display name" : "Ainm taispeána",
     "Headline" : "Ceannlíne",
-    "Organisation" : "Eagraíocht",
+    "Organization" : "Eagraíocht",
     "Role" : "Ról",
     "Pronouns" : "Forainmneacha",
     "Unknown account" : "Cuntas anaithnid",
@@ -275,7 +277,7 @@ OC.L10N.register(
     "A valid Login must be provided" : "Ní mór Logáil Isteach bailí a sholáthar",
     "Login contains whitespace at the beginning or at the end" : "Tá spás bán sa logáil isteach ag an tús nó ag an deireadh",
     "Login must not consist of dots only" : "Níor cheart go gcuimseodh logáil isteach poncanna amháin",
-    "Login is too long" : "Tá logáil isteach ró-fhada",
+    "Username is too long" : "Tá an t-ainm úsáideora rófhada",
     "Login is invalid because files already exist for this user" : "Tá logáil isteach neamhbhailí toisc go bhfuil comhaid ann cheana don úsáideoir seo",
     "Account disabled" : "Díchumasaíodh an cuntas",
     "Login canceled by app" : "Cealaíodh logáil isteach ag an aip",
@@ -288,8 +290,6 @@ OC.L10N.register(
     "Cannot write into \"config\" directory." : "Ní féidir scríobh san eolaire \"config\".",
     "This can usually be fixed by giving the web server write access to the config directory. See %s" : "Is féidir é seo a shocrú de ghnáth trí rochtain scríofa a thabhairt don fhreastalaí gréasáin ar an eolaire cumraíochta. Féach %s",
     "Or, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it. See %s" : "Nó, más fearr leat an comhad config.php a choinneáil léite amháin, socraigh an rogha \"config_is_read_only\" le bheith fíor ann. Féach %s",
-    "Cannot write into \"apps\" directory." : "Ní féidir scríobh isteach sa bhfillteán \"apps\".",
-    "This can usually be fixed by giving the web server write access to the apps directory or disabling the App Store in the config file." : "Is féidir é seo a shocrú de ghnáth trí rochtain scríofa a thabhairt don fhreastalaí gréasáin ar an eolaire apps nó an Siopa Aip a dhíchumasú sa chomhad cumraíochta.",
     "Cannot create \"data\" directory." : "Ní féidir eolaire \"sonraí\" a chruthú.",
     "This can usually be fixed by giving the web server write access to the root directory. See %s" : "Is féidir é seo a shocrú de ghnáth trí rochtain scríofa a thabhairt don fhreastalaí gréasáin ar an bhfréamheolaire. Féach %s",
     "Permissions can usually be fixed by giving the web server write access to the root directory. See %s." : "Is féidir ceadanna a shocrú de ghnáth trí rochtain scríofa a thabhairt don fhreastalaí gréasáin ar an bhfréamheolaire. Féach %s.",
@@ -300,8 +300,6 @@ OC.L10N.register(
     "Please ask your server administrator to install the module." : "Iarr ar riarthóir do fhreastalaí an modúl a shuiteáil le do thoil. ",
     "PHP setting \"%s\" is not set to \"%s\"." : "Níl an socrú PHP \"%s\" socraithe go \"%s\".",
     "Adjusting this setting in php.ini will make Nextcloud run again" : "Má choigeartaítear an socrú seo i php.ini, reáchtálfar Nextcloud arís",
-    "<code>mbstring.func_overload</code> is set to <code>%s</code> instead of the expected value <code>0</code>." : "Tá<code>mbstring.func_overload</code> socraithe go <code>%s</code> in ionad an luacha ionchais<code>0</code>.",
-    "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini." : "Chun an tsaincheist seo a réiteach socraigh <code>mbstring.func_overload</code> go <code>0</code> i do php.ini.",
     "PHP is apparently set up to strip inline doc blocks. This will make several core apps inaccessible." : "Is cosúil go bhfuil PHP socraithe chun bloic doc inlíne a stialladh. Beidh sé seo a dhéanamh ar roinnt aipeanna lárnacha dorochtana.",
     "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Is dócha gur taisce/luasaire ar nós Zend OPcache nó eAccelerator ba chúis leis seo.",
     "PHP modules have been installed, but they are still listed as missing?" : "Tá modúil PHP suiteáilte, ach tá siad liostaithe fós mar in easnamh?",
@@ -326,25 +324,48 @@ OC.L10N.register(
     "Storage is temporarily not available" : "Níl stóráil ar fáil go sealadach",
     "Storage connection timeout. %s" : "Teorainn ama ceangail stórála. %s",
     "To allow this check to run you have to make sure that your Web server can connect to itself. Therefore it must be able to resolve and connect to at least one of its `trusted_domains` or the `overwrite.cli.url`. This failure may be the result of a server-side DNS mismatch or outbound firewall rule." : "Le gur féidir an tseiceáil seo a rith caithfidh tú a chinntiú gur féidir le do fhreastalaí Gréasáin nascadh leis féin. Mar sin caithfidh sé a bheith in ann réiteach agus ceangal a dhéanamh le ceann amháin ar a laghad dá chuid `fearainn_iontaofa` nó an `overwrite.cli.url`. D'fhéadfadh an teip seo a bheith mar thoradh ar mhímheaitseáil DNS ar thaobh an fhreastalaí nó riail balla dóiteáin amach.",
+    "Analyze images" : "Anailísigh íomhánna",
+    "Ask a question about the given images." : "Cuir ceist faoi na híomhánna a thugtar.",
+    "Images" : "Íomhánna",
+    "Images to ask a question about" : "Íomhánna le ceist a chur fúthu",
+    "Question" : "Ceist",
+    "What to ask about the images." : "Cad atá le fiafraí faoi na híomhánna.",
+    "Generated response" : "Freagra ginte",
+    "The answer to the question" : "An freagra ar an gceist",
+    "Audio chat" : "Comhrá fuaime",
+    "Voice chat with the assistant" : "Comhrá gutha leis an gcúntóir",
+    "System prompt" : "Leid córais",
+    "Define rules and assumptions that the assistant should follow during the conversation." : "Sainmhínigh na rialacha agus na toimhdí ba chóir don chúntóir a leanúint le linn an chomhrá.",
+    "Chat voice message" : "Teachtaireacht gutha comhrá",
+    "Describe a task that you want the assistant to do or ask a question." : "Déan cur síos ar thasc ar mhaith leat go ndéanfadh an cúntóir é nó ar cheist a chur.",
+    "Chat history" : "Stair comhrá",
+    "The history of chat messages before the current message, starting with a message by the user." : "Stair na dteachtaireachtaí comhrá roimh an teachtaireacht reatha, ag tosú le teachtaireacht ón úsáideoir.",
+    "Input transcript" : "Tras-scríbhinn ionchuir",
+    "Transcription of the audio input" : "Tras-scríobh an ionchuir fuaime",
+    "Response voice message" : "Teachtaireacht gutha freagartha",
+    "The generated voice response as part of the conversation" : "An freagra gutha a ghintear mar chuid den chomhrá",
+    "Output transcript" : "Tras-scríbhinn aschuir",
+    "Transcription of the audio output" : "Tras-scríobh an aschuir fuaime",
     "Transcribe audio" : "Trascríobh fuaime",
     "Transcribe the things said in an audio" : "Tras-scríobh na rudaí a dúradh i bhfuaim",
     "Audio input" : "Ionchur fuaime",
     "The audio to transcribe" : "Fuaime le tras-scríobh",
     "Transcription" : "Trascríobh",
     "The transcribed text" : "An téacs tras-scríofa",
-    "Chat with an agent" : "Déan comhrá le gníomhaire",
-    "Chat message" : "Teachtaireacht comhrá",
-    "A chat message to send to the agent." : "Teachtaireacht comhrá le seoladh chuig an ngníomhaire.",
+    "Chat by voice with an agent" : "Comhrá gutha le gníomhaire",
+    "Describe a task that you want the agent to do or ask a question." : "Déan cur síos ar thasc ar mhaith leat go ndéanfadh an gníomhaire é nó ar cheist a chur.",
     "Confirmation" : "Daingniú",
     "Whether to confirm previously requested actions: 0 for denial and 1 for confirmation." : "Cibé ar cheart gníomhartha a iarradh roimhe seo a dhearbhú: 0 le séanadh agus 1 le deimhniú.",
     "Conversation token" : "Comhartha comhartha",
     "A token representing the conversation." : "Comhartha a léiríonn an comhrá.",
-    "Generated response" : "Freagra ginte",
-    "The response from the chat model." : "An freagra ón múnla comhrá.",
     "The new conversation token" : "An comhartha comhrá nua",
     "Send this along with the next interaction." : "Seol é seo in éineacht leis an gcéad idirghníomhaíocht eile.",
     "Requested actions by the agent" : "Gníomhartha iarrtha ag an ngníomhaire",
     "Actions that the agent would like to carry out in JSON format." : "Gníomhartha ar mhaith leis an ngníomhaire iad a dhéanamh i bhformáid JSON.",
+    "Chat with an agent" : "Déan comhrá le gníomhaire",
+    "Chat message" : "Teachtaireacht comhrá",
+    "A chat message to send to the agent." : "Teachtaireacht comhrá le seoladh chuig an ngníomhaire.",
+    "The response from the chat model." : "An freagra ón múnla comhrá.",
     "Context write" : "Comhthéacs scríobh",
     "Writes text in a given style based on the provided source material." : "Scríobhann sé téacs i stíl ar leith bunaithe ar an mbunábhar a cuireadh ar fáil.",
     "Writing style" : "Stíl scríbhneoireachta",
@@ -384,9 +405,6 @@ OC.L10N.register(
     "The rewritten text in the desired tone, written by the assistant:" : "An téacs athscríofa sa ton inmhianaithe, scríofa ag an gcúntóir:",
     "Chat" : "Comhrá",
     "Chat with the assistant" : "Comhrá leis an cúntóir",
-    "System prompt" : "Leid córais",
-    "Define rules and assumptions that the assistant should follow during the conversation." : "Sainmhínigh na rialacha agus na toimhdí ba chóir don chúntóir a leanúint le linn an chomhrá.",
-    "Chat history" : "Stair comhrá",
     "The history of chat messages before the current message, starting with a message by the user" : "Stair na dteachtaireachtaí comhrá roimh an teachtaireacht reatha, ag tosú le teachtaireacht ón úsáideoir",
     "Response message" : "Teachtaireacht freagartha",
     "The generated response as part of the conversation" : "An freagra ginte mar chuid den chomhrá",
@@ -450,20 +468,13 @@ OC.L10N.register(
     "Generate headline" : "Gin ceannlíne",
     "Summarizes text by reducing its length without losing key information." : "Déanann sé achoimre ar théacs trína fhad a laghdú gan eochairfhaisnéis a chailliúint.",
     "Extracts topics from a text and outputs them separated by commas." : "Sliocht topaicí as téacs agus aschuir iad scartha le camóga.",
-    "Education Edition" : "Eagrán Oideachais",
-    "File name is a reserved word" : "Focal in áirithe is ea ainm comhaid",
-    "File name contains at least one invalid character" : "Tá carachtar neamhbhailí amháin ar a laghad san ainm comhaid",
-    "File name is too long" : "Tá ainm an chomhaid rófhada",
-    "Users" : "Úsáideoirí",
-    "%1$s shared »%2$s« with you and wants to add:" : "%1$s shared »%2$s« with you and wants to add:",
-    "%1$s shared »%2$s« with you and wants to add" : "%1$s shared »%2$s« with you and wants to add",
-    "»%s« added a note to a file shared with you" : "»%s« added a note to a file shared with you",
-    "Open »%s«" : "Oscail »%s«",
-    "%1$s shared »%2$s« with you" : "Roinn %1$s »%2$s« leat",
-    "%1$s shared »%2$s« with you." : "Roinn %1$s »%2$s« leat.",
-    "Click the button below to open it." : "Cliceáil ar an gcnaipe thíos chun é a oscailt.",
+    "Organisation" : "Eagraíocht",
     "File is currently busy, please try again later" : "Tá an comhad gnóthach faoi láthair, bain triail eile as ar ball le do thoil",
     "Cannot download file" : "Ní féidir an comhad a íoslódáil",
-    "Ensure there is a file called \".ocdata\" in the root of the data directory." : "Cinntigh go bhfuil comhad darb ainm \".ocdata\" i bhfréamh an eolaire sonraí."
+    "Cannot write into \"apps\" directory." : "Ní féidir scríobh isteach sa bhfillteán \"apps\".",
+    "This can usually be fixed by giving the web server write access to the apps directory or disabling the App Store in the config file." : "Is féidir é seo a shocrú de ghnáth trí rochtain scríofa a thabhairt don fhreastalaí gréasáin ar an eolaire apps nó an Siopa Aip a dhíchumasú sa chomhad cumraíochta.",
+    "<code>mbstring.func_overload</code> is set to <code>%s</code> instead of the expected value <code>0</code>." : "Tá<code>mbstring.func_overload</code> socraithe go <code>%s</code> in ionad an luacha ionchais<code>0</code>.",
+    "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini." : "Chun an tsaincheist seo a réiteach socraigh <code>mbstring.func_overload</code> go <code>0</code> i do php.ini.",
+    "Login is too long" : "Tá logáil isteach ró-fhada"
 },
 "nplurals=5; plural=(n==1 ? 0 : n==2 ? 1 : n<7 ? 2 : n<11 ? 3 : 4);");
