@@ -199,8 +199,6 @@ OC.L10N.register(
     "Please ask your server administrator to install the module." : "Solicitați administratorului să instaleze modulul.",
     "PHP setting \"%s\" is not set to \"%s\"." : "Setarea PHP \"%s\" nu este setată la \"%s\".",
     "Adjusting this setting in php.ini will make Nextcloud run again" : "Ajustând aceste setări în php.ini va permite ca Nextcloud să funcționeze din nou",
-    "<code>mbstring.func_overload</code> is set to <code>%s</code> instead of the expected value <code>0</code>." : "<code>mbstring.func_overload</code> este setată la <code>%s</code> în locul valorii așteptate <code>0</code>.",
-    "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini." : "Pentru a remedia problema setați <code>mbstring.func_overload</code> la <code>0</code> în php.ini.",
     "PHP is apparently set up to strip inline doc blocks. This will make several core apps inaccessible." : "PHP este aparent configurat pentru a elimina blocurile de documente inline. Acest lucru va face mai multe aplicații de bază inaccesibile.",
     "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Aceasta se datorează probabil unui accelerator/cache precum Zend OPcache sau eAccelerator.",
     "PHP modules have been installed, but they are still listed as missing?" : "Modulele PHP au fost instalate, dar apar ca lipsind?",
@@ -238,6 +236,8 @@ OC.L10N.register(
     "File is currently busy, please try again later" : "Fișierul este blocat momentan, încercați din nou mai târziu",
     "Cannot download file" : "Fișierul nu se poate descărca",
     "Cannot write into \"apps\" directory." : "Nu se poate scrie în directorul \"apps\".",
-    "This can usually be fixed by giving the web server write access to the apps directory or disabling the App Store in the config file." : "Aceasta se poate remedia permițând serverului web să acceseze directorul aplicațiilor sau dezactivând App Store în fișierul de configurație."
+    "This can usually be fixed by giving the web server write access to the apps directory or disabling the App Store in the config file." : "Aceasta se poate remedia permițând serverului web să acceseze directorul aplicațiilor sau dezactivând App Store în fișierul de configurație.",
+    "<code>mbstring.func_overload</code> is set to <code>%s</code> instead of the expected value <code>0</code>." : "<code>mbstring.func_overload</code> este setată la <code>%s</code> în locul valorii așteptate <code>0</code>.",
+    "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini." : "Pentru a remedia problema setați <code>mbstring.func_overload</code> la <code>0</code> în php.ini."
 },
 "nplurals=3; plural=(n==1?0:(((n%100>19)||((n%100==0)&&(n!=0)))?2:1));");
