@@ -129,6 +129,8 @@ OC.L10N.register(
     "Settings" : "設定",
     "Log out" : "登出",
     "Accounts" : "帳戶",
+    "Bluesky" : "Bluesky",
+    "View %s on Bluesky" : "在 Bluesky 上查看 %s",
     "Email" : "電郵地址",
     "Mail %s" : "郵件 %s",
     "Fediverse" : "Fediverse",
@@ -144,7 +146,7 @@ OC.L10N.register(
     "About" : "關於",
     "Display name" : "顯示名稱",
     "Headline" : "標題",
-    "Organisation" : "機構",
+    "Organization" : "生產力",
     "Role" : "角色",
     "Pronouns" : "代名詞",
     "Unknown account" : "帳戶不詳",
@@ -288,8 +290,6 @@ OC.L10N.register(
     "Cannot write into \"config\" directory." : "無法寫入 \"config\" 目錄",
     "This can usually be fixed by giving the web server write access to the config directory. See %s" : "允許網頁伺服器寫入 \"config\" 目錄通常可以解決這個問題，詳見 %s",
     "Or, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it. See %s" : "或者，如果您比較希望保留 config.php 的唯讀狀態，請在該設定檔中將 \"config_is_read_only\" 設定為 true。見%s",
-    "Cannot write into \"apps\" directory." : "無法寫入 \"apps\" 目錄",
-    "This can usually be fixed by giving the web server write access to the apps directory or disabling the App Store in the config file." : "這通常可以通過授予網絡伺服器對應用程式目錄的寫存取權限或在配置檔案中禁用 App Store 來解決。",
     "Cannot create \"data\" directory." : "無法建立 \"data\" 目錄",
     "This can usually be fixed by giving the web server write access to the root directory. See %s" : "開放網頁伺服器存取根目錄通常就可以修正這個問題，詳見 %s",
     "Permissions can usually be fixed by giving the web server write access to the root directory. See %s." : "開放網頁伺服器存取根目錄通常就可以修正權限問題，詳見 %s",
@@ -300,8 +300,6 @@ OC.L10N.register(
     "Please ask your server administrator to install the module." : "請詢問系統管理員來安裝這些模組",
     "PHP setting \"%s\" is not set to \"%s\"." : "PHP 設定值 \"%s\" 沒有被設定為 \"%s\"",
     "Adjusting this setting in php.ini will make Nextcloud run again" : "調整 php.ini 中的設定，使 Nextcloud 重新運作",
-    "<code>mbstring.func_overload</code> is set to <code>%s</code> instead of the expected value <code>0</code>." : "<code>mbstring.func_overload</code> 應該要被設定成 <code>0</code> 而不是目前的設定 <code>%s</code>。",
-    "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini." : "為了修正這個問題，請到 php.ini 將 <code>mbstring.func_overload</code> 的值改為 <code>0</code>。",
     "PHP is apparently set up to strip inline doc blocks. This will make several core apps inaccessible." : "PHP 已經設定成「剪除 inline doc block」模式，這將會使幾個核心應用程式無法使用",
     "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "這大概是由快取或是加速器像是 Zend OPcache， eAccelerator 造成的",
     "PHP modules have been installed, but they are still listed as missing?" : "你已經安裝了指定的 PHP 模組，可是還是顯示為找不到嗎？",
@@ -326,25 +324,48 @@ OC.L10N.register(
     "Storage is temporarily not available" : "儲存空間暫時無法使用",
     "Storage connection timeout. %s" : "儲存空間連線逾時。%s",
     "To allow this check to run you have to make sure that your Web server can connect to itself. Therefore it must be able to resolve and connect to at least one of its `trusted_domains` or the `overwrite.cli.url`. This failure may be the result of a server-side DNS mismatch or outbound firewall rule." : "若要允許執行此檢查，您必須確保您的網路伺服器可以連線到其自身。因此，其必須可以解析並連線到 `trusted_domains` 或 `overwrite.cli.url` 至少其中一個。此失敗可能是因為伺服器端 DNS 不符或連出防火牆規則造成的。",
+    "Analyze images" : "分析圖像",
+    "Ask a question about the given images." : "請問您能對所提供的圖片提出一個問題嗎？",
+    "Images" : "圖像",
+    "Images to ask a question about" : "要提出問題的圖像",
+    "Question" : "問題",
+    "What to ask about the images." : "要問什麼關於圖像的問題。",
+    "Generated response" : "已產生的回應",
+    "The answer to the question" : "問題的答案",
+    "Audio chat" : "語音聊天",
+    "Voice chat with the assistant" : "與小幫手使用語音聊天",
+    "System prompt" : "系統提示詞",
+    "Define rules and assumptions that the assistant should follow during the conversation." : "定義小幫手在對話期間應遵守的規則與假設。",
+    "Chat voice message" : "聊天語音訊息",
+    "Describe a task that you want the assistant to do or ask a question." : "描述您希望小幫手執行的任務或提出問題。",
+    "Chat history" : "聊天紀錄",
+    "The history of chat messages before the current message, starting with a message by the user." : "在目前訊息之前的聊天記錄，從用戶的訊息開始。",
+    "Input transcript" : "輸入轉錄",
+    "Transcription of the audio input" : "語音輸入轉錄",
+    "Response voice message" : "回應語音訊息",
+    "The generated voice response as part of the conversation" : "産生的語音回應作為對話的一部分",
+    "Output transcript" : "輸出轉錄",
+    "Transcription of the audio output" : "音訊輸出轉錄",
     "Transcribe audio" : "抄錄音頻為文字",
     "Transcribe the things said in an audio" : "轉錄音訊中所說的話",
     "Audio input" : "音頻輸入",
     "The audio to transcribe" : "要轉錄的音頻",
     "Transcription" : "轉錄",
     "The transcribed text" : "已轉錄的文字",
-    "Chat with an agent" : "與 agent 聊天",
-    "Chat message" : "聊天訊息",
-    "A chat message to send to the agent." : "要發送給 agent 的聊天消息。",
+    "Chat by voice with an agent" : "與 agent 語音聊天",
+    "Describe a task that you want the agent to do or ask a question." : "描述您希望 agent 執行的任務或提出問題。",
     "Confirmation" : "確認",
     "Whether to confirm previously requested actions: 0 for denial and 1 for confirmation." : "是否確認之前請求的操作：0 表示拒絕，1 表示確認。",
     "Conversation token" : "對話權杖",
     "A token representing the conversation." : "一個代表對話的權杖。",
-    "Generated response" : "已產生的回應",
-    "The response from the chat model." : "來自聊天模型的回應。",
     "The new conversation token" : "新對話權杖",
     "Send this along with the next interaction." : "將此與下一次互動一起發送。",
     "Requested actions by the agent" : "Agent 所要求的操作",
     "Actions that the agent would like to carry out in JSON format." : "Agent 希望以 JSON 格式執行的操作。",
+    "Chat with an agent" : "與 agent 聊天",
+    "Chat message" : "聊天訊息",
+    "A chat message to send to the agent." : "要發送給 agent 的聊天消息。",
+    "The response from the chat model." : "來自聊天模型的回應。",
     "Context write" : "寫作情境",
     "Writes text in a given style based on the provided source material." : "根據提供的來源資料以指定的風格編寫文字。",
     "Writing style" : "寫作風格",
@@ -384,9 +405,6 @@ OC.L10N.register(
     "The rewritten text in the desired tone, written by the assistant:" : "助手以所需語氣重寫的文本：",
     "Chat" : "聊天",
     "Chat with the assistant" : "與小幫手聊天",
-    "System prompt" : "系統提示詞",
-    "Define rules and assumptions that the assistant should follow during the conversation." : "定義小幫手在對話期間應遵守的規則與假設。",
-    "Chat history" : "聊天紀錄",
     "The history of chat messages before the current message, starting with a message by the user" : "目前訊息開始之前的聊天紀錄，從用戶的訊息開始",
     "Response message" : "回應訊息",
     "The generated response as part of the conversation" : "作為對話一部份產生的回應",
@@ -450,8 +468,13 @@ OC.L10N.register(
     "Generate headline" : "産生標題",
     "Summarizes text by reducing its length without losing key information." : "通過減少文字長度來總結而不丟失關鍵資訊。",
     "Extracts topics from a text and outputs them separated by commas." : "從文字中提取主題並輸出，並用逗號分隔。",
+    "Organisation" : "機構",
     "File is currently busy, please try again later" : "檔案目前忙碌中，請稍候再試",
     "Cannot download file" : "無法下載檔案",
+    "Cannot write into \"apps\" directory." : "無法寫入 \"apps\" 目錄",
+    "This can usually be fixed by giving the web server write access to the apps directory or disabling the App Store in the config file." : "這通常可以通過授予網絡伺服器對應用程式目錄的寫存取權限或在配置檔案中禁用 App Store 來解決。",
+    "<code>mbstring.func_overload</code> is set to <code>%s</code> instead of the expected value <code>0</code>." : "<code>mbstring.func_overload</code> 應該要被設定成 <code>0</code> 而不是目前的設定 <code>%s</code>。",
+    "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini." : "為了修正這個問題，請到 php.ini 將 <code>mbstring.func_overload</code> 的值改為 <code>0</code>。",
     "Login is too long" : "帳號太長了"
 },
 "nplurals=1; plural=0;");
